
## CATO-CLI - query.appCategory:

### Usage for query.appCategory:

```bash
catocli query appCategory -h

catocli query appCategory '{}'

catocli query appCategory '{"names": ["google", "amazon"]}'
```

#### Operation Arguments for query.appCategory ####
`names` [Array<String>] - (optional) List of names or descriptions to search for (case-insensitive substring match). If empty, returns all.
